@@ -62,6 +62,7 @@ class EtfValuation(ValuationBase, Mixin):
     pcf1 = Column(Float)
 
 
-register_schema(providers=['joinquant'], db_name='valuation', schema_base=ValuationBase)
+register_schema(providers=['joinquant'], db_name='valuation', schema_base=ValuationBase, entity_type='stock')
 
-__all__ = ['StockValuation', 'EtfValuation']
+# the __all__ is generated
+__all__ = ['StockValuation', 'EtfValuation']
\ No newline at end of file
