@@ -64,6 +64,7 @@ class CrossMarketSummary(OverallBase, Mixin):
     quota_daily_balance = Column(Float)
 
 
-register_schema(providers=['joinquant', 'exchange'], db_name='overall', schema_base=OverallBase)
+register_schema(providers=['joinquant', 'exchange'], db_name='overall', schema_base=OverallBase, entity_type='stock')
 
-__all__ = ['StockSummary', 'MarginTradingSummary', 'CrossMarketSummary']
+# the __all__ is generated
+__all__ = ['StockSummary', 'MarginTradingSummary', 'CrossMarketSummary']
\ No newline at end of file
