@@ -5,6 +5,7 @@ from sqlalchemy.orm import relationship
 
 from zvt.contract import Mixin
 from zvt.contract.register import register_schema
+from zvt.utils import to_string
 
 TraderBase = declarative_base()
 
@@ -15,19 +16,18 @@ class TraderInfo(TraderBase, Mixin):
     # 机器人名字
     trader_name = Column(String(length=128))
 
-    entity_ids = Column(String(length=1024))
     entity_type = Column(String(length=128))
-    exchanges = Column(String(length=128))
-    codes = Column(String(length=128))
     start_timestamp = Column(DateTime)
     end_timestamp = Column(DateTime)
     provider = Column(String(length=32))
     level = Column(String(length=32))
     real_time = Column(Boolean)
     kdata_use_begin_time = Column(Boolean)
+    kdata_adjust_type = Column(String(length=32))
 
 
 # account stats of every day
+@to_string
 class AccountStats(TraderBase, Mixin):
     __tablename__ = 'account_stats'
 
@@ -44,6 +44,11 @@ class AccountStats(TraderBase, Mixin):
     # 市值+cash
     all_value = Column(Float)
 
+    # 盈亏
+    profit = Column(Float)
+    # 盈亏比例
+    profit_rate = Column(Float)
+
     # 收盘计算
     closing = Column(Boolean)
 
@@ -72,7 +77,10 @@ class Position(TraderBase, Mixin):
     # 平均做空价格
     average_short_price = Column(Float)
 
+    # 盈亏
     profit = Column(Float)
+    # 盈亏比例
+    profit_rate = Column(Float)
     # 市值 或者 占用的保证金(方便起见，总是100%)
     value = Column(Float)
     # 交易类型(0代表T+0,1代表T+1)
@@ -100,4 +108,5 @@ class Order(TraderBase, Mixin):
 
 register_schema(providers=['zvt'], db_name='trader_info', schema_base=TraderBase)
 
+# the __all__ is generated
 __all__ = ['TraderInfo', 'AccountStats', 'Position', 'Order']
