@@ -114,6 +114,6 @@ if __name__ == '__main__':
     init_log('jq_china_stock_{}_kdata.log'.format(args.level))
     JqChinaIndexKdataRecorder(level=level, sleeping_time=0, codes=codes, real_time=False).run()
 
-    print(get_kdata(entity_id='index_sz_000001', limit=10))
+    print(get_kdata(entity_id='index_sh_000001', limit=10))
 # the __all__ is generated
 __all__ = ['JqChinaIndexKdataRecorder']
\ No newline at end of file
